OnBuilder<T> class

Explicitly listenTo one or more injected state and reinvoke its onBuilder callback each time an injected state emits a notification.

For each OnBuilder widget flavor there is method like equivalent:

//Widget-like
OnBuilder(
    listenTo: counter,
    builder: () => Text('${counter.state}'),
),

//Method-like
counter.rebuild(
    () => Text('{counter.state}'),
),
//
//Widget-like
OnBuilder.data(
    listenTo: counter,
    builder: (data) => Text('$data')),
),

//Method-like
counter.rebuild.onData(
    (data) => Text(data),
),

//Widget-like
OnBuilder.all(
    listenTo: counter,
    onIdle: () => Text('onIdle'),
    onWaiting: () => Text('onWaiting'),
    onError: (err, errorRefresh) => Text('onError'),
    onData: (data) => Text('$data'),

)

//Method-like
counter.rebuild.onAll(
    onIdle: () => Text('onIdle'),
    onWaiting: () => Text('onWaiting'),
    onError: (err, errorRefresh) => Text('onError'),
    onData: (data) => Text('$data'),
),
//
//Widget-like
OnBuilder.orElse(
    listenTo: counter,
    onWaiting: () => Text('onWaiting'),
    orElse: (_) => Text('{counter.state}'),

),

//Method-like
counter.rebuild.onOrElse(
    onWaiting: () => Text('onWaiting'),
    orElse: (_) => Text('{counter.state}'),
),
Inheritance
Available extensions

Constructors

OnBuilder({Key? key, IObservable<T>? listenTo, List<IObservable>? listenToMany, required Widget builder(), SideEffects<T>? sideEffects, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild})
Explicitly listenTo one or more injected state and reinvoke its onBuilder callback each time an injected state emits a notification.
OnBuilder.all({Key? key, IObservable<T>? listenTo, List<IObservable>? listenToMany, OnIdle? onIdle, required OnWaiting onWaiting, required OnError onError, required OnData<T> onData, SideEffects<T>? sideEffects, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild})
Explicitly listenTo one or more injected state and reinvoke its onBuilder callback each time an injected state emits a notification.
OnBuilder.bindingObserver({Key? key, IObservable<T>? listenTo, required Widget builder(), SideEffects<T>? sideEffects, ShouldRebuild? shouldRebuild, void didChangeAppLifecycleState(BuildContext context, AppLifecycleState state)?, void didChangeLocales(BuildContext context, List<Locale>? locale)?})
Create a widget that registers with the Widgets layer binding. Used to track the app life cycle (AppLifecycleState).
factory
OnBuilder.create({Key? key, @Deprecated('Use creator instead') ReactiveModel<T> create()?, T creator()?, SideEffects<T>? sideEffects, required Widget builder(ReactiveModel<T> rm)})
If creator is null, a ReactiveModel
OnBuilder.createFuture({Key? key, required Future<T> creator(), T? initialState, SideEffects<T>? sideEffects, required Widget builder(ReactiveModel<T> rm)})
Create a ReactiveModel state from a future and listen to it
OnBuilder.createStream({Key? key, required Stream<T> creator(), T? initialState, SideEffects<T>? sideEffects, required Widget builder(ReactiveModel<T> rm)})
Create a ReactiveModel state from a stream and listen to it
OnBuilder.data({Key? key, IObservable<T>? listenTo, List<IObservable>? listenToMany, required Widget builder(T data), SideEffects<T>? sideEffects, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild})
Explicitly listenTo one or more injected state and reinvoke its onBuilder callback each time an injected state emits a notification.
OnBuilder.orElse({Key? key, IObservable<T>? listenTo, List<IObservable>? listenToMany, Widget onIdle()?, Widget onWaiting()?, Widget onError(dynamic error, void refreshError())?, Widget onData(T data)?, required Widget orElse(T data), SideEffects<T>? sideEffects, ShouldRebuild? shouldRebuild, Object? watch()?, String? debugPrintWhenRebuild})
Explicitly listenTo one or more injected state and reinvoke its onBuilder callback each time an injected state emits a notification.

Properties

cleaners List<VoidCallback>
finalinherited
debugPrintWhenRebuild String?
finalinherited
didChangeDependencies → void Function(BuildContext context, ReactiveModel<T>? model)?
finalinherited
didUpdateWidget → void Function(BuildContext context, ReactiveModel<T>? model, MyStatefulWidget<T> oldWidget)?
finalinherited
dispose → void Function(BuildContext context, ReactiveModel<T>? model)?
finalinherited
hashCode int
The hash code for this object.
no setterinherited
initState → void Function(BuildContext context, ReactiveModel<T>? model)?
finalinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
makeRefreshable Widget

Available on Widget?, provided by the WidgetExtension extension

Make your any widget refreshable with RefreshIndicator on top
no setter
observers List<ReactiveModelImp> Function(BuildContext context)
finalinherited
onSetState → void Function(BuildContext, SnapState<T>, ReactiveModel<T>)?
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldRebuild → ShouldRebuild?
Whether to rebuild the widget after state notification.
finalinherited
sideEffects SideEffects<T>?
finalinherited

Methods

addMaterialWidget() Material

Available on Widget, provided by the GenericExtensions extension

addTooltipWidget(String toolTip) Tooltip

Available on Widget, provided by the GenericExtensions extension

borderRadius([BorderRadiusGeometry? borderRadius]) Widget

Available on Widget, provided by the GenericExtensions extension

boxDecoration([BoxDecoration? boxDecoration]) Widget

Available on Widget, provided by the GenericExtensions extension

builder(BuildContext context, SnapState<T> snap, ReactiveModel<T> rm) Widget
inherited
center({double? heightFactor, double? widthFactor}) Widget

Available on Widget?, provided by the WidgetExtension extension

set parent widget in center
colorFilter([ColorFilter? colorFilter]) Widget

Available on Widget, provided by the GenericExtensions extension

set parent widget in center
cornerRadiusWithClipRRect(double radius) ClipRRect

Available on Widget?, provided by the WidgetExtension extension

add corner radius
cornerRadiusWithClipRRectOnly({int bottomLeft = 0, int bottomRight = 0, int topLeft = 0, int topRight = 0}) ClipRRect

Available on Widget?, provided by the WidgetExtension extension

add custom corner radius each side
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → _MyStatefulWidgetState<T>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
expand({int flex = 1}) Widget

Available on Widget?, provided by the WidgetExtension extension

add Expanded to parent widget
fit({BoxFit? fit, AlignmentGeometry? alignment}) Widget

Available on Widget?, provided by the WidgetExtension extension

add FittedBox to parent widget
flexible({int flex = 1, FlexFit? fit}) Widget

Available on Widget?, provided by the WidgetExtension extension

add Flexible to parent widget
launch<T>(BuildContext context, {bool isNewTask = false, PageRouteAnimation? pageRouteAnimation, Duration? duration, String? routeName, Object? routeArguments}) Future<T?>

Available on Widget?, provided by the WidgetExtension extension

Launch a new screen
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onTap(Function? function, {BorderRadius? borderRadius, Color? splashColor, Color? hoverColor, Color? highlightColor, Color? focusColor, WidgetStateProperty<Color?>? overlayColor}) Widget

Available on Widget?, provided by the WidgetExtension extension

add tap to parent widget
opacity({required double opacity, int durationInSecond = 1, Duration? duration}) Widget

Available on Widget?, provided by the WidgetExtension extension

add opacity to parent widget
paddingAll(double padding) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding all
paddingBottom(double bottom) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding bottom
paddingDirectional({double start = 0.0, double top = 0.0, double end = 0.0, double bottom = 0.0}) Widget

Available on Widget?, provided by the WidgetExtension extension

paddingLeft(double left) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding left
paddingOnly({double top = 0.0, double left = 0.0, double bottom = 0.0, double right = 0.0}) Padding

Available on Widget?, provided by the WidgetExtension extension

return custom padding from each side
paddingRight(double right) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding right
paddingSymmetric({double vertical = 0.0, double horizontal = 0.0}) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding symmetric
paddingTop(double top) Padding

Available on Widget?, provided by the WidgetExtension extension

return padding top
rotate({required double angle, bool transformHitTests = true, Offset? origin}) Widget

Available on Widget?, provided by the WidgetExtension extension

add rotation to parent widget
scale({required double scale, Offset? origin, AlignmentGeometry? alignment, bool transformHitTests = true}) Widget

Available on Widget?, provided by the WidgetExtension extension

add scaling to parent widget
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
tooltip({required String msg}) Widget

Available on Widget?, provided by the WidgetExtension extension

toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
translate({required Offset offset, bool transformHitTests = true, Key? key}) Widget

Available on Widget?, provided by the WidgetExtension extension

add translate to parent widget
validate({Widget value = const SizedBox()}) Widget

Available on Widget?, provided by the WidgetExtension extension

Validate given widget is not null and returns given value if null.
visible(bool visible, {Widget? defaultWidget}) Widget

Available on Widget?, provided by the WidgetExtension extension

set visibility
withHeight(double height) SizedBox

Available on Widget?, provided by the WidgetExtension extension

With custom height
withRoundedCorners({Color backgroundColor = whiteColor, BorderRadius borderRadius = const BorderRadius.all(Radius.circular(8.0)), LinearGradient? gradient, BoxBorder? border, List<BoxShadow>? boxShadow, DecorationImage? decorationImage, BoxShape boxShape = BoxShape.rectangle}) Container

Available on Widget?, provided by the WidgetExtension extension

withScroll({ScrollPhysics? physics, EdgeInsetsGeometry? padding, Axis scrollDirection = Axis.vertical, ScrollController? controller, DragStartBehavior dragStartBehavior = DragStartBehavior.start, bool? primary, required bool reverse}) Widget

Available on Widget?, provided by the WidgetExtension extension

withShaderMask(List<Color> colors, {BlendMode blendMode = BlendMode.srcATop}) Widget

Available on Widget?, provided by the WidgetExtension extension

Wrap with ShaderMask widget
withShaderMaskGradient(Gradient gradient, {BlendMode blendMode = BlendMode.srcATop}) Widget

Available on Widget?, provided by the WidgetExtension extension

Wrap with ShaderMask widget Gradient
withShadow({Color bgColor = whiteColor, Color shadowColor = Colors.black12, dynamic blurRadius = 10.0, dynamic spreadRadius = 0.0, Offset offset = const Offset(0.0, 0.0), LinearGradient? gradient, BoxBorder? border, DecorationImage? decorationImage, BoxShape boxShape = BoxShape.rectangle}) Container

Available on Widget?, provided by the WidgetExtension extension

withSize({double width = 0.0, double height = 0.0}) SizedBox

Available on Widget?, provided by the WidgetExtension extension

With custom height and width
withTooltip({required String msg}) Widget

Available on Widget?, provided by the WidgetExtension extension

Validate given widget is not null and returns given value if null.
withVisibility(bool visible, {Widget? replacement, bool maintainAnimation = false, bool maintainState = false, bool maintainSize = false, bool maintainSemantics = false, bool maintainInteractivity = false}) Visibility

Available on Widget?, provided by the WidgetExtension extension

set widget visibility
withWidth(double width) SizedBox

Available on Widget?, provided by the WidgetExtension extension

With custom width

Operators

operator ==(Object other) bool
The equality operator.
inherited